// https://trac-hacks.org/wiki/TracKeywordsPlugin
// This will append a "Keywords" section to the HTML page.
// The keyword list is pre-defined via TRAC-ini file.
// Each keyword field is click-able and allows to toggle 
// the corresponding keyword in the ticket "keywords" property field.
jQuery(function($) {

  field_id = document.getElementById('tags') ? "tags" : "field-keywords";
  
  // toggle (remove or add) a keyword tag to the field
  function addRemoveTag(w) {
    var el = document.getElementById(field_id);
    var orig = el.value;
    // remove the keyword including white spaces and separator, match case-insensitive
    var newval = orig.replace(new RegExp('\\W*\\b' + w + '\\b','i'), '');
    var link = document.getElementById('trac-keyword-' + w);
    if (orig != newval) { // remove tag.
        if(link) link.className = '';
    } else { // append tag
        newval = orig + (orig ? ' ' : '') + w;
        if(link) link.className = 'trac-keyword';
    }
    //strip leading and trailing white spaces and separator
    el.value = newval.replace(/^\W+|\W+$/, '');
  }
  
  if($('#trac-keywords').length > 0) {return}// avoid duplicate insertion of keyword section
  var $fieldset = $('<fieldset id="trac-keywords" />');
  $fieldset.append('<legend>Add Keywords</legend>')
  $ul = $('<ul></ul>');
  $fieldset.append($ul)
  var field = document.getElementById(field_id).value;
  // case-insensitive: going to compare lower case 
  field = field.toLowerCase();
  // This regex splits the content of the field at non-word characters.
  var resource_keywords = field.split(/\W+/);
  // Iterate over each keyword defined in the Trac ini-file.
  $.each(trac_keywords, function(i, item) {
    $ul.append($('<li><a href="#">' + item[0] + '</a></li> ')
      .attr({
        'title': item[1],
        'id': 'trac-keyword-' + item[0],
        'class': $.inArray(item[0].toLowerCase(), resource_keywords) != -1 ? 'trac-keyword': '',
      })
      .on('click', function() {
        addRemoveTag($(this).text());
        return false;
      }));
  })

  $("div.ticket #properties").after($fieldset);
  $("div.wiki #changeinfo").after($fieldset);

})
